# Draw motif logo
Python3 scripts to draw motif logo in svg format


## Installation

```
pip3 install drawlogo
```

## Requirements
```
python >= 3.6
```

## Usage
```
drawlogo <options>...
```
or 
```
python3 -m drawlogo <options>...
```
To get full usage description one can execute:
```
drawlogo --help
```
The drawlogo tool is maintained by Sergey Abramov and Alexandr Boytsov.